/virtualbox/{uuid} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /virtualbox/{uuid}

Contents

- /virtualbox/{uuid}
  - GET /virtualbox/{uuid}
    - Parameters
    - Response status codes
    - Output
    - Sample session
  - PUT /virtualbox/{uuid}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /virtualbox/{uuid}
    - Parameters
    - Response status codes

## GET /virtualbox/{uuid}

Get a VirtualBox VM instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 200: Success
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_start_index |  | integer | adapter index from which to start using adapters
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
uuid | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Sample session

    curl -i -X GET 'http://localhost:8000/virtualbox/{uuid}'

    GET /virtualbox/{uuid} HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 346
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/virtualbox/{uuid}

    {
        "adapter_start_index": 0,
        "adapter_type": "Intel PRO/1000 MT Desktop (82540EM)",
        "adapters": 0,
        "console": 2001,
        "enable_remote_console": false,
        "headless": false,
        "name": "VMTEST",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "uuid": "92802e17-faa3-4c88-8a4a-3a486fcc7165",
        "vmname": "VMTEST"
    }

## PUT /virtualbox/{uuid}

Update a VirtualBox VM instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 200: Instance updated
- 409: Conflict
- 404: Instance doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_start_index |  | integer | adapter index from which to start using adapters
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name |  | string | VirtualBox VM instance name
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_start_index |  | integer | adapter index from which to start using adapters
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
uuid | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

## DELETE /virtualbox/{uuid}

Delete a VirtualBox VM instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »